<?php

namespace Drupal\pf_alerta\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Push Framework Alerta settings for this site.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'pf_alerta_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['pf_alerta.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('pf_alerta.settings');
    $form['active'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Active'),
      '#default_value' => $config->get('active'),
    ];
    $form['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Url'),
      '#default_value' => $config->get('url'),
    ];
    $form['apikey'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $config->get('apikey'),
    ];
    $form['environment'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Environment'),
      '#default_value' => $config->get('environment'),
    ];
    $form['host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Host'),
      '#default_value' => $config->get('host'),
    ];
    $form['pid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('GitLab Project ID'),
      '#default_value' => $config->get('pid'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('pf_alerta.settings')
      ->set('active', $form_state->getValue('active'))
      ->set('url', $form_state->getValue('url'))
      ->set('apikey', $form_state->getValue('apikey'))
      ->set('environment', $form_state->getValue('environment'))
      ->set('host', $form_state->getValue('host'))
      ->set('pid', $form_state->getValue('pid'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
